@@ -7,13 +7,12 @@ SimpleCov.formatter = SimpleCov::Formatter::MultiFormatter[
   Coveralls::SimpleCov::Formatter
 ]
 SimpleCov.start do
-  add_filter 'vendor/cache'
+  add_filter "vendor/cache"
 end
 
 require "tmuxinator"
 require "factory_girl"
 
-
 FactoryGirl.find_definitions
 
 RSpec.configure do |config|
@@ -22,21 +21,23 @@ end
 
 # Copied from minitest.
 def capture_io
-  begin
-    require 'stringio'
+  require "stringio"
 
-    captured_stdout, captured_stderr = StringIO.new, StringIO.new
+  captured_stdout = StringIO.new
+  captured_stderr = StringIO.new
 
-    orig_stdout, orig_stderr = $stdout, $stderr
-    $stdout, $stderr         = captured_stdout, captured_stderr
+  orig_stdout = $stdout
+  orig_stderr = $stderr
 
-    yield
+  $stdout = captured_stdout
+  $stderr = captured_stderr
 
-    return captured_stdout.string, captured_stderr.string
-  ensure
-    $stdout = orig_stdout
-    $stderr = orig_stderr
-  end
+  yield
+
+  return captured_stdout.string, captured_stderr.string
+ensure
+  $stdout = orig_stdout
+  $stderr = orig_stderr
 end
 
 def tmux_config(options = {})
@@ -46,11 +47,11 @@ def tmux_config(options = {})
     "bell-on-alert off",
   ]
 
-  if base_index  = options.fetch(:base_index) {1}
+  if base_index = options.fetch(:base_index) { 1 }
     standard_options << "base-index #{base_index}"
   end
 
-  if pane_base_index  = options.fetch(:pane_base_index) {1}
+  if pane_base_index = options.fetch(:pane_base_index) { 1 }
     standard_options << "pane-base-index #{pane_base_index}"
   end
 
